@@ -603,7 +603,7 @@ setMethod(f = "getObservationById",
 			verbose = verbose, inspect = inspect)
 	
 	cat("[sos4R] Received response (size:", object.size(.responseString),
-			"bytes), starting parsing ...\n")
+			"bytes), parsing ...\n")
 	
 	# responseFormat starts with text/xml OR the response string is XML content,
 	# for example an exeption (which is xml even if request wants something else
