@@ -1,7 +1,7 @@
 # ESRI Development Center (EDC) Entwickerforum Time & Space
-# Mnster, 17. - 18.02.2011
+# Muenster, 17. - 18.02.2011
 # 
-# Author: Daniel Nst
+# Author: Daniel Nuest
 # sos4R Webseite (downloads, news): http://www.nordholmen.net/sos4r
 ################################################################################
 
@@ -12,38 +12,38 @@
 #	decoding.
 
 # Workshop #####################################################################
-# - Skript ffnen in RGui, dann mit Strg + R aktuelle Zeile oder ausgewhlten
-# Code ausfhren.
-# - Fr R-Neulinge gibt es Tipps und Tricks gleich mit :-).
+# - Skript oeffnen in RGui, dann mit Strg + R aktuelle Zeile oder ausgewaehlten
+# Code ausfuehren.
+# - Fuer R-Neulinge gibt es Tipps und Tricks gleich mit :-).
 # - Funktionen/Features und Baustellen von sos4R immer wieder zwischendurch.
 
 
 ##### Installation #############################################################
-# Dependencies installieren (werden nicht aufgelst wenn von Datei installiert 
+# Dependencies installieren (werden nicht aufgeloest wenn von Datei installiert 
 # wird):
 #install.packages("sos4R")
 # Package laden
 library("sos4R")
 # sessionInfo()
 
-# Weitere packages die bentigt werden fr Kartendarstellungen:
+# Weitere packages die benoetigt werden fuer Kartendarstellungen:
 #install.packages("maps"); install.packages("mapdata"); install.packages("maptools")
 
-##### Untersttzte und Standard-Features #######################################
+##### Unterstuetzte und Standard-Features #######################################
 SosSupportedOperations() # jeweils eine entsprechende R Funktion
 SosSupportedConnectionMethods()
 
 SosSupportedResponseFormats()
 SosSupportedServiceVersions()
-# Exchangeability feature: Parsing und encoding-Functionen knnen einfach 
+# Exchangeability feature: Parsing und encoding-Functionen koennen einfach 
 # ausgetauscht werden (Liste mit Funktionen)
 
 SosSupportedResponseModes()
 
 SosSupportedResultModels()
-## Exkurs: "O&M Profil": sos4R untersttzt, aus offensichtlichen Grnden
+## Exkurs: "O&M Profil": sos4R unterstuetzt, aus offensichtlichen Gruenden
 # (52North Innovation Price for Geoinformatics), aber auch aus Ermangelung von
-# allgemeinen Alternativen, das Profil des 52N SOS. Dies gilt auch fr die 
+# allgemeinen Alternativen, das Profil des 52N SOS. Dies gilt auch fuer die 
 # folgenden Operatoren:
 SosSupportedSpatialOperators()
 SosSupportedTemporalOperators()
@@ -55,7 +55,7 @@ SosDefaults()
 
 
 ##### Verbindung zu einem SOS erstellen ########################################
-# Minimal-Server fr Niederlande, nur 1 Monat Daten:
+# Minimal-Server fuer Niederlande, nur 1 Monat Daten:
 aqe <- SOS(url = "http://v-sos.uni-muenster.de:8080/SosAirQuality/sos")
 
 # TIPP: Methoden beginnen mit 'sos...'
@@ -65,17 +65,17 @@ sosUrl(aqe)
 sosVersion(aqe)
 sosMethod(aqe)
 
-# Standard R Funktionen werden oft untersttzt:
+# Standard R Funktionen werden oft unterstuetzt:
 print(aqe)
 summary(aqe)
 
 
 ##### Capabilities #############################################################
-# Öffnen im Browser: http://v-sos.uni-muenster.de:8080/SosAirQuality/sos?service=SOS&request=GetCapabilities
-# Wurden bereits runtergeladen:
+# Oeffne Seite im Browser: http://v-sos.uni-muenster.de:8080/SosAirQuality/sos?service=SOS&request=GetCapabilities
+# Capabilities wurden jedoch bereits runtergeladen und geparsed:
 sosCaps(aqe)
 
-# OWS Common = OGC Web Services Common wurden implementiert fr GetCapabilities
+# OWS Common = OGC Web Services Common wurden implementiert fuer GetCapabilities
 # Request und Exception Handling (OwsExceptionReport), modelliert als Klassen
 # und parsing-Funktionen.
 
@@ -88,7 +88,7 @@ sosContents(aqe)
 #************#
 # Aufgabe 01 #
 #************#
-# Wie knnen die weiteren Sektionen der Capabilities abgefragt werden?
+# Wie koennen die weiteren Sektionen der Capabilities abgefragt werden?
 # Die Elemente sind ServiceIdentification, ServiceProvider, OperationsMetadata,
 # Filter_Capabilities.
 
@@ -105,8 +105,8 @@ sosOperation(aqe, "GetObservation"); sosOperations(aqe)[["GetObservation"]]
 
 
 ##### Zugriffsfunktionen #######################################################
-# Weitere wichtige Elemente der Capabilities, sind ber getter bzw.  accessor 
-# abrufbar, da sie spter zum erstellen der Requests benötigt werden:
+# Weitere wichtige Elemente der Capabilities, sind ueber getter bzw.  accessor 
+# abrufbar, da sie spaeter zum erstellen der Requests benoetigt werden:
 sosOfferingIds(aqe) # == names(sosOfferings(aqe))
 
 sosOfferings(aqe) # > print(sosOfferings(aqe))
@@ -114,7 +114,7 @@ sosOfferings(aqe) # > print(sosOfferings(aqe))
 # Indexierungsarten (generisch R):
 sosOfferings(aqe)[2:3]				# Subliste
 sosOfferings(aqe)[[3]]				# einzelnes Element
-sosOfferings(aqe)[["PM10"]]		# ber die ID 
+sosOfferings(aqe)[["PM10"]]		# ueber die ID 
 
 pm10.off <- sosOfferings(aqe)[["PM10"]]
 
@@ -129,7 +129,7 @@ sosGetCRS(pm10.off)
 #************#
 # Aufgabe 02 #
 #************#
-# Welche der Funktionen aus diesem Abschnitt funktionieren auch fr SOS-Objekte?
+# Welche der Funktionen aus diesem Abschnitt funktionieren auch fuer SOS-Objekte?
 # Was gibt es dabei zu beachten?
 
 sosTime(aqe) # benutzt GetObservation operation description
@@ -144,17 +144,17 @@ sosGetCRS(aqe)
 # Welches der Offerings hat die meisten Sensoren?
 # TIPP: ?length
 
-# Lsung 1:
+# Loesung 1:
 lapply(X = sosProcedures(aqe), FUN = length)
 lapply(X = sosProcedures(sosOfferings(aqe)), FUN = length)
 
-# Lsung 2:
+# Loesung 2:
 procedures <- sosProcedures(sosOfferings(aqe))
 length(procedures[[1]])
 length(procedures[[2]])
 length(procedures[[3]])
 
-# Lsung 3:
+# Loesung 3:
 length(sosProcedures(sosOfferings(aqe)[[1]]))
 length(sosProcedures(sosOfferings(aqe)[[2]]))
 length(sosProcedures(sosOfferings(aqe)[[3]]))
@@ -183,16 +183,16 @@ title(main = paste("Offering '", sosId(pm10.off), "' at", sosTitle(aqe),
 #************#
 # Aufgabe 03 #
 #************#
-# Wie knnen alle Offerings geplottet werden?
-# TIPP fr Fortgeschrittene: ?text
+# Wie koennen alle Offerings geplottet werden?
+# TIPP fuer Fortgeschrittene: ?text
 
-# Lsung 1: "copy und paste"
+# Loesung 1: "copy und paste"
 plot(map.lines, col = "grey50", lwd = 1)
 plot(sosOfferings(aqe)[[1]], add = TRUE, lwd = 3, border = "green")
 plot(sosOfferings(aqe)[[2]], add = TRUE, lwd = 3, border = "blue")
 plot(sosOfferings(aqe)[[3]], add = TRUE, lwd = 3, border = "red")
 
-# Lsung 2:
+# Loesung 2:
 plot(map.lines, col = "grey50", lwd = 1) # neuen Hintergrundplot erzeugen.
 plot(aqe, add = TRUE, lwd = 2)
 
@@ -200,8 +200,8 @@ plot(aqe, add = TRUE, lwd = 2)
 ##### Sensor Metadaten abfragen ################################################
 sensor2 <- describeSensor(aqe, sosProcedures(pm10.off)[[2]])
 sensor2		
-sensor2@xml # Viel Information, einzelne Details über Getter abfragbar, dies
-			# verlangt aber Konformität mit SensorML Profile for Discovery
+sensor2@xml # Viel Information, einzelne Details ueber Getter abfragbar, dies
+			# verlangt aber Konformitaet mit SensorML Profile for Discovery
 
 # Getter:
 sosId(sensor2)
@@ -224,7 +224,7 @@ plot(sensor2, add = TRUE, pch = 7, cex = 2)
 ##### Messungen abfragen #######################################################
 # TIPP: "inspect" benutzen um die requests und responses kennen zu lernen!
 
-##### Temporre Ausschnitte ####################################################
+##### Temporaere Ausschnitte ####################################################
 # 1 Stunde im Dezember, alle Daten zu viel wegen parallelen Anfragen!
 # TIPP: sosCreate... - Funktionen helfen korrekte Strukturen zu erzeugen:
 aug2007.6Hrs = sosCreateEventTimeList(sosCreateTimePeriod(sos = aqe,
@@ -236,7 +236,7 @@ aug2007.obs <- getObservation(sos = aqe, inspect = TRUE,
 		offering = pm10.off, eventTime = aug2007.6Hrs)
 warnings()
 
-# PROBLEM: Nicht untersttzte Datenfelder werden abgefragt! Konverter ergnzen:
+# PROBLEM: Nicht unterstuetzte Datenfelder werden abgefragt! Konverter ergaenzen:
 aqe.converters <- SosDataFieldConvertingFunctions(
 		"http://giv-genesis.uni-muenster.de:8080/SOR/REST/phenomenon/OGC/Concentration[PM10]" = sosConvertDouble,
 		"http://giv-genesis.uni-muenster.de:8080/SOR/REST/phenomenon/OGC/Concentration.NO2." = sosConvertDouble,
@@ -248,10 +248,10 @@ aqe.converters <- SosDataFieldConvertingFunctions(
 aqe <- SOS(sosUrl(aqe), dataFieldConverters = aqe.converters)
 
 # Nochmaliges daten abrufen, diesmal alternativ auf Basis der offering ID:
-# Daten fr ganz Deutschland!
+# Daten fuer ganz Deutschland!
 aug2007.obs <- getObservation(sos = aqe, offering = "NO2", #verbose = TRUE,
 		eventTime = aug2007.6Hrs)
-# Parsing dauert lnger als request -> wenig Daten in vielen Observations, hoher
+# Parsing dauert laenger als request -> wenig Daten in vielen Observations, hoher
 # XML overhead?
 
 # Nur einige Stationen, mit 'inspect' Parameter
@@ -265,13 +265,13 @@ print(aug2007.obs.small)
 str(aug2007.obs.small, max.level = 5) # limitieren der Strukturtiefe
 
 ## OmObservationCollection und OmObservation modellieren O&M Datenmodell
-# generisch in R. Dies gibt es in begrenztem Umfang auch fr GML, SWE, SensorML,
+# generisch in R. Dies gibt es in begrenztem Umfang auch fuer GML, SWE, SensorML,
 # OGC, SA, ... Namespaces.
-## Mittelfristig denkbar: Nicht nur De- und Encoding der Elemente wie sie fr 
-# den SOS bentigt werden, sondern generische Transformationsfunktionen
+## Mittelfristig denkbar: Nicht nur De- und Encoding der Elemente wie sie fuer 
+# den SOS benoetigt werden, sondern generische Transformationsfunktionen
 # (Stichwort "coercion") zwischen O&M/GML/SWE Datenmodell und sp, base-R, ...
 
-# ObservationCollection ist auf vielfltige Art indizierbar:
+# ObservationCollection ist auf vielfaeltige Art indizierbar:
 aug2007.obs[[1]]
 aug2007.obs[10:14]
 aug2007.obs[c(17,21)]
@@ -291,7 +291,7 @@ sosBoundedBy(aug2007.obs, bbox = TRUE)
 sosProcedures(aug2007.obs)
 sosObservedProperties(aug2007.obs[[10]])
 
-# Wie knnen die Koordinaten fr die Observations 10 bis 20 abgefragt werden?
+# Wie koennen die Koordinaten fuer die Observations 10 bis 20 abgefragt werden?
 
 sosCoordinates(aug2007.obs[10:20])
 
@@ -299,17 +299,17 @@ sosCoordinates(aug2007.obs[10:20])
 # sosFeatureIds(aug2007.obs[10:12])?
 
 sosFeatureIds(aug2007.obs)[10:12]
-# Fragt alle feature ids ab und nimmt von dieser zusammengefgten Liste die
+# Fragt alle feature ids ab und nimmt von dieser zusammengefuegten Liste die
 # Elemente 42 bis 44:
 str(sosFeatureIds(aug2007.obs)[10:12]) # List of 3 character
 
 sosFeatureIds(aug2007.obs[10:12])
-# Fragt observations 10 bis 14 ab und ruft auf dieser Liste (!) fr jedes
+# Fragt observations 10 bis 14 ab und ruft auf dieser Liste (!) fuer jedes
 # Element die Funktion sosFeatureIds(...) auf.
 str(sosFeatureIds(aug2007.obs[10:12])) # List of 3 Lists
 
 
-##### Tatschliche Daten erforschen ############################################
+##### Tatsaechliche Daten erforschen ############################################
 # sosResult(...) ist die wichtigste Methode:
 sosResult(aug2007.obs[[1]])
 
@@ -327,7 +327,7 @@ help("data.frame")
 # HTML help:
 help.start()
 
-# Wie kann ich die Daten verschiedene Stationen zusammenfgen?
+# Wie kann ich die Daten verschiedene Stationen zusammenfuegen?
 sosResult(aug2007.obs[20:21])			# Result der 20. und 21. Observations
 sosResult(aug2007.obs)[20:21,]		# Zeile 20, 21 von allen (!) Daten
 
@@ -350,27 +350,27 @@ aug2007.data[1:3,]
 # Aufgabe 06 #
 #************#
 # Was sind der maximale/minimale, der Durchschnittswert, der Median und die
-# Quantile von NO2 fr alle heruntergeladenen Daten?
+# Quantile von NO2 fuer alle heruntergeladenen Daten?
 
-# Lsung 1:
+# Loesung 1:
 max(aug2007.data[["Concentration.NO2."]])
 min(aug2007.data[["Concentration.NO2."]])
 mean(aug2007.data[["Concentration.NO2."]])
 median(aug2007.data[["Concentration.NO2."]])
 quantile(aug2007.data[["Concentration.NO2."]])
 
-# Lsung 2:
+# Loesung 2:
 summary(aug2007.data)
 summary(aug2007.data[["Concentration.NO2."]])
 
-# Wie ist das Phnomen Concentration.NO2. definiert?
+# Wie ist das Phaenomen Concentration.NO2. definiert?
 
 # Antwort: "Amount of nitrogen dioxide (NO2) as a fraction of host medium"
 
-# Lsung 1:
+# Loesung 1:
 # Browser: http://giv-genesis.uni-muenster.de:8080/SOR/REST/phenomenon/OGC/Concentration.NO2.
 
-# Lsung 2: XML parsing
+# Loesung 2: XML parsing
 # Nur um zu zeigen dass Erweitern mit Paket XML nicht so schlimm ist:
 definition <- getURL("http://giv-genesis.uni-muenster.de:8080/SOR/REST/phenomenon/OGC/Concentration.NO2.")
 definition.xml <- xmlParse(definition)
@@ -378,7 +378,7 @@ getNodeSet(doc = definition.xml, path = "//gml:description/text()")[[1]]
 
 ##### Thematische Ausschnitte ##################################################
 
-# Ein Phnomen (auch wenn es sowieso nur eines ist) fr eine Station, ein Jahr:
+# Ein Phaenomen (auch wenn es sowieso nur eines ist) fuer eine Station, ein Jahr:
 no2.off <- sosOfferings(aqe)[["NO2"]]
 time.2007 = sosCreateEventTimeList(sosCreateTimePeriod(sos = aqe,
 				begin = as.POSIXct("2007/01/01"),
@@ -386,8 +386,8 @@ time.2007 = sosCreateEventTimeList(sosCreateTimePeriod(sos = aqe,
 
 sosProcedures(no2.off)
 # Beachte das Benennungsschema: "DE" "NW", "NL"
-# Stationsbersicht: http://www.eea.europa.eu/themes/air/airbase/map-stations
-# Station auswhlen -> Meta Data
+# Stationsuebersicht: http://www.eea.europa.eu/themes/air/airbase/map-stations
+# Station auswaehlen -> Meta Data
 myStationID <- "NL00639" # "DESH024"
 idx <- grep(pattern = myStationID, x = sosProcedures(no2.off))
 myStation <- sosProcedures(no2.off)[idx]
@@ -396,7 +396,7 @@ myStation
 sosObservedProperties(no2.off)
 
 # Filtern mit observed property nicht notwendig, da sowieso ein Offering nur 
-# ein Phnomen liefert.
+# ein Phaenomen liefert.
 obs.myStation.2007 <- getObservation(sos = aqe,
 		offering = no2.off, # inspect = TRUE,
 		procedure = myStation,
@@ -428,7 +428,7 @@ lines(p ~ result.myStation.2007[["SamplingTime"]], col = 'blue',lwd = 4)
 hist(result.myStation.2007[["Concentration.NO2."]])
 
 
-##### Rumliche Ausschnitte ####################################################
+##### Raeumliche Ausschnitte ####################################################
 #SosSupportedSpatialOperators()
 sosBoundedBy(no2.off)
 
@@ -455,7 +455,7 @@ sosBoundedBy(obs.2007.bbox, bbox = TRUE)
 # Aufgabe 07 #
 #************#
 # Wann und wo (Koordinaten) sind Daten des Offerings NO2 im Vergleich zu den
-# abgefragten Daten verfgbar?
+# abgefragten Daten verfuegbar?
 
 # Wo:
 sosBoundedBy(no2.off, bbox = TRUE)
@@ -476,8 +476,8 @@ length(sosProcedures(obs.2007.bbox))
 result.bbox <- sosResult(obs.2007.bbox, coordinates = TRUE)
 obs.crs <- sosGetCRS(obs.2007.bbox)
 
-# Die Spalten lon, lat werden fr die Koordinaten des SPDF, die anderen Spalten
-# fr die Daten des SPDF benutzt.
+# Die Spalten lon, lat werden fuer die Koordinaten des SPDF, die anderen Spalten
+# fuer die Daten des SPDF benutzt.
 no2.spdf.bbox <- SpatialPointsDataFrame(
 		coords = result.bbox[,c("lon", "lat")],
 		data = result.bbox[,
@@ -485,10 +485,10 @@ no2.spdf.bbox <- SpatialPointsDataFrame(
 		proj4string = obs.crs)
 summary(no2.spdf.bbox)
 
-# Viele Funktionen aus sp, ... nun verfgbar
+# Viele Funktionen aus sp, ... nun verfuegbar
 bbox(no2.spdf.bbox)
 
-# Im Vergleich zu den Daten ohne bounding box, hierbei wird eine "Abkrzung"
+# Im Vergleich zu den Daten ohne bounding box, hierbei wird eine "Abkuerzung"
 # verwendet wenn die Spaltennamen bekannt sind (sind sie bei 52N SOS)
 obs.no2.2007 <- getObservation(sos = aqe, # inspect = TRUE,
 		offering = no2.off)
@@ -497,11 +497,11 @@ no2.spdf <- as(obs.no2.2007, "SpatialPointsDataFrame")
 summary(no2.spdf)
 bbox(no2.spdf)
 
-# Coercion einer einzelnen Observation ist ebenfalls mglich, jedoch bis jetzt
-# auf SpatialPointsDataFrame beschrnkt. Hier ist natrlich aufwendiges/
-# komfortables/mchtiges Mapping zwischen O&M Datenstrukturen und sp/R/spacetime
+# Coercion einer einzelnen Observation ist ebenfalls moeglich, jedoch bis jetzt
+# auf SpatialPointsDataFrame beschraenkt. Hier ist natuerlich aufwendiges/
+# komfortables/maechtiges Mapping zwischen O&M Datenstrukturen und sp/R/spacetime
 # Datenmodellen ein langfristiges Ziel. Potentiell sogar in beide Richtungen,
-# (Transactional SOS Profile). Funktioniert (nur) fr 52N Profil oder hnliche.
+# (Transactional SOS Profile). Funktioniert (nur) fuer 52N Profil oder aehnliche.
 spdf.1 <- as(obs.2007.bbox[[1]], "SpatialPointsDataFrame")
 summary(spdf.1)
 levels(spdf.1[["FeatureOfInterest"]])
@@ -516,9 +516,9 @@ coordinates(no2.spdf) # nur Koordinates, coordinates ist eine sp-Funktion
 plot(x = map.lines, col = "grey")
 plot(no2.spdf, pch = 20, col = "blue", add = TRUE)
 
-# Frage Daten fr eine beliebige Woche ab und erzeuge einen data.frame, benutze
-# auch den SOS fr Deutschland. Wichtig: kleiner zeitlicher oder rumlicher
-# Ausschnitt, damit der Service nicht beransprucht wird.
+# Frage Daten fuer eine beliebige Woche ab und erzeuge einen data.frame, benutze
+# auch den SOS fuer Deutschland. Wichtig: kleiner zeitlicher oder raeumlicher
+# Ausschnitt, damit der Service nicht ueberansprucht wird.
 aqe.de <- SOS(url = "http://giv-uw.uni-muenster.de:8080/AQE/sos",
 		dataFieldConverters = SosDataFieldConvertingFunctions(aqe.converters))
 
@@ -527,7 +527,7 @@ aqe.de <- SOS(url = "http://giv-uw.uni-muenster.de:8080/AQE/sos",
 ##### Demos ####################################################################
 demo(package = "sos4R")
 
-# Demos laufen lassen (enhalten weiterfhrende Beispiele mit plots usw.):
+# Demos laufen lassen (enhalten weiterfuehrende Beispiele mit plots usw.):
 #demo("weathersos")
 #demo("pegel")
 #demo("airquality")
